import { Construct } from 'constructs';
import { IVpc } from 'aws-cdk-lib/aws-ec2';
import { Cluster } from 'aws-cdk-lib/aws-ecs';
import { IAuroraServerlessTemporalDatastoreProps, ITemporalDatastore } from './TemporalDatastore';
import { TemporalVersion } from './TemporalVersion';
import { RemovalPolicy } from 'aws-cdk-lib';
import { FileSystem } from 'aws-cdk-lib/aws-efs';
import { TemporalConfiguration } from './configurations/TemporalConfiguration';
import { INamespace } from 'aws-cdk-lib/aws-servicediscovery';
import { FrontendService, HistoryService, MatchingService, WebService, WorkerService } from './services/ServerServices';
import { ITemporalServiceMachineProps } from './services/BaseService';
export interface ITemporalClusterProps {
    readonly clusterName?: string;
    readonly temporalVersion?: TemporalVersion;
    readonly vpc: IVpc;
    readonly ecsCluster?: Cluster;
    readonly removalPolicy?: RemovalPolicy;
    readonly datastore?: ITemporalDatastore;
    readonly datastoreOptions?: Omit<IAuroraServerlessTemporalDatastoreProps, 'vpc' | 'engine'>;
    readonly services?: {
        autoSetup?: Partial<ITemporalServiceProps>;
        frontend?: Partial<ITemporalServiceProps>;
        history?: Partial<ITemporalServiceProps>;
        matching?: Partial<ITemporalServiceProps>;
        worker?: Partial<ITemporalServiceProps>;
        web?: Partial<ITemporalServiceProps> & {
            enabled?: boolean;
        };
        defaults?: Partial<ITemporalServiceProps>;
    };
    readonly cloudMapRegistration?: {
        namespace: INamespace;
        serviceName: string;
    };
    readonly metrics?: {
        engine?: 'disabled' | 'prometheus' | 'cloudwatch';
        prometheusServer?: string;
    };
}
interface ITemporalServiceProps {
    machine: ITemporalServiceMachineProps;
}
export declare class TemporalCluster extends Construct {
    readonly name: string;
    readonly temporalVersion: TemporalVersion;
    readonly temporalConfig: TemporalConfiguration;
    readonly ecsCluster: Cluster;
    readonly configEfs: FileSystem;
    readonly services: {
        frontend?: FrontendService;
        matching?: MatchingService;
        history?: HistoryService;
        worker?: WorkerService;
        web?: WebService;
    };
    constructor(scope: Construct, id: string, clusterProps: ITemporalClusterProps);
    private resolveServiceProps;
    private getOrCreateDatastore;
    private getOrCreateEcsCluster;
    private setupConfigFileSystem;
    private wireUpNetworkAuthorizations;
}
export {};
