import { IVpc, SubnetSelection } from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
import { ITemporalDatastore, TemporalCluster, TemporalVersion } from '../..';
import { ITemporalDatabaseProps } from './TemporalDatabaseResource';
interface ITemporalDatabaseProviderProps {
    readonly temporalVersion: TemporalVersion;
    readonly vpc: IVpc;
    readonly vpcSubnets: SubnetSelection;
}
export declare class TemporalDatabaseProvider extends Construct {
    /**
     * We create a single instance of this provider by VPC and Temporal Version pair, at the stack level.
     * Privileges for that single instance's lambda function are then expanded to include network access
     * to each datastore and temporal frontend nodes, as well as read access to each datastore access secrets.
     */
    static getOrCreate(scope: Construct, props: ITemporalDatabaseProviderProps, databaseProps: ITemporalDatabaseProps): string;
    private readonly provider;
    private readonly lambdaFunction;
    constructor(scope: Construct, id: string, props: ITemporalDatabaseProviderProps);
    expandPrivilegesToDatastore(datastore: ITemporalDatastore): void;
    expandPrivilegesToTemporalCluster(temporalCluster: TemporalCluster): void;
}
export {};
