"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemporalDatabaseProvider = void 0;
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_ec2_1 = require("aws-cdk-lib/aws-ec2");
const aws_lambda_1 = require("aws-cdk-lib/aws-lambda");
const aws_lambda_nodejs_1 = require("aws-cdk-lib/aws-lambda-nodejs");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const custom_resources_1 = require("aws-cdk-lib/custom-resources");
const constructs_1 = require("constructs");
const AdminToolsLayer_1 = require("./AdminToolsLayer");
class TemporalDatabaseProvider extends constructs_1.Construct {
    constructor(scope, id, props) {
        super(scope, id);
        this.node.addDependency(props.vpc);
        this.lambdaFunction = new aws_lambda_nodejs_1.NodejsFunction(this, 'OnEventHandler', {
            entry: require.resolve('./TemporalDatabaseHandler'),
            runtime: aws_lambda_1.Runtime.NODEJS_14_X,
            handler: 'onEvent',
            vpc: props.vpc,
            vpcSubnets: props.vpcSubnets,
            layers: [AdminToolsLayer_1.AdminToolsLayer.getOrCreate(this, props.temporalVersion)],
            timeout: aws_cdk_lib_1.Duration.minutes(5),
        });
        this.provider = new custom_resources_1.Provider(this, 'Provider', {
            onEventHandler: this.lambdaFunction,
            logRetention: aws_logs_1.RetentionDays.FIVE_DAYS,
        });
    }
    /**
     * We create a single instance of this provider by VPC and Temporal Version pair, at the stack level.
     * Privileges for that single instance's lambda function are then expanded to include network access
     * to each datastore and temporal frontend nodes, as well as read access to each datastore access secrets.
     */
    static getOrCreate(scope, props, databaseProps) {
        const stack = aws_cdk_lib_1.Stack.of(scope);
        // const id = `CustomResource-TemporalDatabaseProvider-${
        //     props.vpc.node.addr
        // }-${props.temporalVersion.version.replace(/[.]/g, '_')}`;
        const id = 'CustomResource-TemporalDatabaseProvider';
        const x = stack.node.tryFindChild(id) ?? new TemporalDatabaseProvider(stack, id, props);
        x.expandPrivilegesToDatastore(databaseProps.datastore);
        return x.provider.serviceToken;
    }
    expandPrivilegesToDatastore(datastore) {
        datastore.connections.allowDefaultPortFrom(this.lambdaFunction);
        datastore.secret.grantRead(this.lambdaFunction);
    }
    expandPrivilegesToTemporalCluster(temporalCluster) {
        // FIXME: Make this cleaner and do not require that we provide the port number
        temporalCluster.services.frontend.fargateService.connections.allowFrom(this.lambdaFunction, aws_ec2_1.Port.tcp(7233));
    }
}
exports.TemporalDatabaseProvider = TemporalDatabaseProvider;
//# sourceMappingURL=TemporalDatabaseProvider.js.map